#[non_exhaustive]pub enum Request {
Destroy,
GetXdgOutput {
id: New<ZxdgOutputV1>,
output: WlOutput,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Destroy
destroy the xdg_output_manager object
Using this request a client can tell the server that it is not going to use the xdg_output_manager object anymore.
Any objects already created through this instance are not affected.
This is a destructor, once received this object cannot be used any longer.
GetXdgOutput
create an xdg output from a wl_output
This creates a new xdg_output object for the given wl_output.
Implementations